DecorationStyle class

Annotations

Constructors

DecorationStyle({required DecorationType type, List<DecorationMatch> getMatches(String text)?, Color backgroundColor = Colors.transparent, TextStyle? textStyle, ValueChanged<String>? onTap, bool deleteOnTap = true})
const

Properties

backgroundColor → Color
final
deleteOnTap → bool
final
getMatches → List<DecorationMatch> Function(String text)?
final
hashCode → int
The hash code for this object.
no setterinherited
onTap → ValueChanged<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle?
final
type → DecorationType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited