PerfectTextController class

Inheritance
Annotations

Constructors

PerfectTextController({FocusNode? focusNode, bool selectAllOnFocus = false, bool readyOnly = false, void onTextChange(String value)?, void onFocusChange(bool value)?, List<DecorationStyle> decorations = const []})

Properties

decorations → List<DecorationStyle>
final
focusNode → FocusNode
final
hasFocus → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
onFocusChange ↔ void Function(bool value)?
getter/setter pair
onTextChange ↔ ValueChanged<String>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
rxText → ValueNotifier<String>
final
selection ↔ TextSelection
The currently selected range within text.
getter/setter pairinherited
text ↔ String
The current string the user is editing.
getter/setter pairinherited-getteroverride-setter
value ↔ TextEditingValue
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
buildTextSpan({required BuildContext context, TextStyle? style, required bool withComposing}) → TextSpan
Builds TextSpan from current editing value.
override
clear() → void
Set the value to empty.
inherited
clearComposing() → void
Set the composing region to an empty range.
inherited
copyWith({FocusNode? focusNode, bool selectAllOnFocus = false, bool readyOnly = false, void onTextChange(String value)?, void onFocusChange(bool value)?}) → PerfectTextController
dispose() → void
Discards any resources used by the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
requestFocus([FocusNode? node]) → void
requestFocusWithSelectAll([FocusNode? node]) → void
selectAll() → void
toString() → String
A string representation of this object.
inherited
unfocus() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

focused ↔ PerfectTextController?
getter/setter pair